multidim.PointCloud.from_multisample_multilabel — GDA Toolbox v1.0 Manual

# multidim.PointCloud.from_multisample_multilabel

classmethod `PointCloud.` `from_multisample_multilabel`(list_of_samples, list_of_labels, equal_priors=True, normalize_domain=False)

  Produce a single labeled and weighted pointcloud from a list of samples and labels of those samples.

  Parameters: | list_of_samples : A list (or np array) of np arrays. Each such array is considered to be a sample of N points in R^d. N can vary between entries, but d cannot. list_of_labels : A list of labels. Labels can be anything, but it is covenient to use strings like “red” and “blue”. list_of_labels[i] is the label for the points in list_of_samples[i]. equal_priors: Re-normalize weights so that each label is equally likely. Default: True normalize_domain: Use SVD/PCA to re-shape the original data to be roughy spherical. This should allow better learning via CDER. Default: False

#### Previous topic

multidim.PointCloud.from_distances

#### Next topic

multidim.PointCloud.gaussian_fit